boofun.visualization.latex\_export
==================================

.. automodule:: boofun.visualization.latex_export


   .. rubric:: Functions

   .. autosummary::

      export_comparison_table
      export_cube_tikz
      export_fourier_tikz
      export_influences_tikz
      export_spectrum_table

   .. rubric:: Classes

   .. autosummary::

      LaTeXExporter
